# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes


#### Private Classes

* `peadm::setup::convert_node_manager`: Used during the peadm::convert plan
* `peadm::setup::convert_pre20197`: Defines configuration needed for converting PE 2018
* `peadm::setup::node_manager`: Configures PEAdm's required node groups
* `peadm::setup::node_manager_yaml`: Set up the node_manager.yaml file in the temporary Bolt confdir

### Functions

* [`peadm::assert_supported_architecture`](#peadmassert_supported_architecture): Assert that the architecture given is a supported one
* [`peadm::assert_supported_bolt_version`](#peadmassert_supported_bolt_version): Assert that the Bolt executable running PEAdm is a supported version
* [`peadm::assert_supported_pe_version`](#peadmassert_supported_pe_version): Assert that the PE version given is supported by PEAdm
* [`peadm::bolt_version`](#peadmbolt_version)
* [`peadm::certname`](#peadmcertname): Return the certname of the given target-like input
* [`peadm::convert_hash`](#peadmconvert_hash): converts two arrays into hash
* [`peadm::convert_status`](#peadmconvert_status): Transforms a value in a human readable status with or without colors
* [`peadm::determine_status`](#peadmdetermine_status): Produces a summarized hash of the given status data
* [`peadm::fail_on_transport`](#peadmfail_on_transport): Fails if any nodes have the chosen transport.  Useful for excluding PCP when it's not appopriate
* [`peadm::file_content_upload`](#peadmfile_content_upload)
* [`peadm::file_or_content`](#peadmfile_or_content)
* [`peadm::flatten_compact`](#peadmflatten_compact)
* [`peadm::generate_pe_conf`](#peadmgenerate_pe_conf): Generate a pe.conf file in JSON format
* [`peadm::get_targets`](#peadmget_targets): Accept undef or a SingleTargetSpec, and return an Array[Target, 1, 0]. This differs from get_target() in that:   - It returns an Array[Target
* [`peadm::node_manager_yaml_location`](#peadmnode_manager_yaml_location)
* [`peadm::oid`](#peadmoid)
* [`peadm::plan_step`](#peadmplan_step)
* [`peadm::wait_until_service_ready`](#peadmwait_until_service_ready): A convenience function to help remember port numbers for services and handle running the wait_until_service_ready task

### Data types

* [`Peadm::Pe_version`](#peadmpe_version)
* [`Peadm::Pem`](#peadmpem)
* [`Peadm::SingleTargetSpec`](#peadmsingletargetspec): A SingleTargetSpec represents any String, Target or single-element array of one or the other that can be passed to get_targets() to return an

### Tasks

* [`agent_install`](#agent_install): Install the Puppet agent from a master
* [`agent_upgrade`](#agent_upgrade): Upgrade the target system using upgrade.bash from a master
* [`backup_classification`](#backup_classification): A task to call the classification api and write to file
* [`cert_data`](#cert_data): Return certificate data related to the Puppet agent
* [`code_manager`](#code_manager): Perform various code manager actions
* [`code_sync_status`](#code_sync_status): A task to confirm code is in sync accross the cluster for clusters with code manager configured
* [`divert_code_manager`](#divert_code_manager): Divert the code manager live-dir setting
* [`download`](#download): Download a file using curl
* [`enable_replica`](#enable_replica): Execute the enable replica puppet command
* [`filesize`](#filesize): Return the size of a file in bytes
* [`get_peadm_config`](#get_peadm_config): Run on a PE primary node to return the currently configured PEAdm parameters
* [`infrastatus`](#infrastatus): Runs puppet infra status and returns the output
* [`mkdir_p_file`](#mkdir_p_file): Create a file with the specified content at the specified location
* [`mv`](#mv): Wrapper task for mv command
* [`pe_install`](#pe_install): Install Puppet Enterprise from a tarball
* [`pe_uninstall`](#pe_uninstall): Uninstall Puppet Enterprise
* [`precheck`](#precheck): Return pre-check information about a system
* [`provision_replica`](#provision_replica): Execute the replica provision puppet command
* [`puppet_infra_upgrade`](#puppet_infra_upgrade): Execute the puppet infra upgrade command
* [`puppet_runonce`](#puppet_runonce): Run the Puppet agent one time
* [`rbac_token`](#rbac_token): Get and save an rbac token for the root user, admin rbac user
* [`read_file`](#read_file): Read the contents of a file
* [`sign_csr`](#sign_csr): Submit a certificate signing request
* [`ssl_clean`](#ssl_clean): Clean an agent's certificate
* [`submit_csr`](#submit_csr): Submit a certificate signing request
* [`wait_until_service_ready`](#wait_until_service_ready): Return when the orchestrator service is healthy, or timeout after 15 seconds

### Plans

#### Public Plans

* [`peadm::backup`](#peadmbackup): Backup the core user settings for puppet infrastructure
* [`peadm::convert`](#peadmconvert): Convert an existing PE cluster to a PEAdm-managed cluster
* [`peadm::install`](#peadminstall): Install a new PE cluster
* [`peadm::modify_certificate`](#peadmmodify_certificate): Modify the certificate of one or more targets
* [`peadm::status`](#peadmstatus): Return status information from one or more PE clusters in a table format
* [`peadm::upgrade`](#peadmupgrade): Upgrade a PEAdm-managed cluster

#### Private Plans

* `peadm::add_compiler`: Add a new compiler to a PE architecture or replace an existing one with new configuration.
* `peadm::add_replica`: Replace a replica host for a Standard or Large architecture.
Supported use cases:
1: The existing replica is broken, we have a fresh new VM we want to provision the replica to.
   The new replica should have the same certname as the broken one.
* `peadm::misc::divert_code_manager`: This plan exists to account for a scenario where a PE XL
* `peadm::modify_cert_extensions`
* `peadm::subplans::configure`: Configure first-time classification and DR setup
* `peadm::subplans::install`: Perform initial installation of Puppet Enterprise Extra Large
* `peadm::subplans::modify_certificate`
* `peadm::uninstall`: Single-entry-point plan for uninstalling Puppet Enterprise
* `peadm::util::insert_csr_extension_requests`
* `peadm::util::retrieve_and_upload`
* `peadm::util::sanitize_pg_pe_conf`

## Classes

## Functions

### <a name="peadmassert_supported_architecture"></a>`peadm::assert_supported_architecture`

Type: Puppet Language

Assert that the architecture given is a supported one

#### `peadm::assert_supported_architecture(TargetSpec $primary_host, Variant[TargetSpec, Undef] $replica_host = undef, Variant[TargetSpec, Undef] $primary_postgresql_host = undef, Variant[TargetSpec, Undef] $replica_postgresql_host = undef, Variant[TargetSpec, Undef] $compiler_hosts = undef)`

The peadm::assert_supported_architecture function.

Returns: `Hash`

##### `primary_host`

Data type: `TargetSpec`



##### `replica_host`

Data type: `Variant[TargetSpec, Undef]`



##### `primary_postgresql_host`

Data type: `Variant[TargetSpec, Undef]`



##### `replica_postgresql_host`

Data type: `Variant[TargetSpec, Undef]`



##### `compiler_hosts`

Data type: `Variant[TargetSpec, Undef]`



### <a name="peadmassert_supported_bolt_version"></a>`peadm::assert_supported_bolt_version`

Type: Puppet Language

Checks if the current Bolt version matches the SemVerRange defined in $supported_bolt_version
Fails the calling plan if false, does nothing if true.
Accepts a parameter for the $supported_bolt_version for unit testing purposes

#### `peadm::assert_supported_bolt_version()`

Checks if the current Bolt version matches the SemVerRange defined in $supported_bolt_version
Fails the calling plan if false, does nothing if true.
Accepts a parameter for the $supported_bolt_version for unit testing purposes

Returns: `Struct[{'supported' => Boolean}]`

### <a name="peadmassert_supported_pe_version"></a>`peadm::assert_supported_pe_version`

Type: Puppet Language

Assert that the PE version given is supported by PEAdm

#### `peadm::assert_supported_pe_version(String $version, Boolean $permit_unsafe_versions = false)`

The peadm::assert_supported_pe_version function.

Returns: `Struct[{'supported' => Boolean}]` true if the version is supported, raise error otherwise

##### `the`

Data type: `String`

version number to check

##### `version`

Data type: `String`



##### `permit_unsafe_versions`

Data type: `Boolean`



### <a name="peadmbolt_version"></a>`peadm::bolt_version`

Type: Ruby 4.x API

The peadm::bolt_version function.

#### `peadm::bolt_version()`

The peadm::bolt_version function.

Returns: `Any`

### <a name="peadmcertname"></a>`peadm::certname`

Type: Puppet Language

This function accepts a variety of data types which could represent single
targets, and returns the certname corresponding to the input.

For Target objects, or arrays of a single Target object, a "certname" var can
be set, which determines that target's certname. Otherwise, the target's name
is its certname. For strings, the certname is equal to the string. Undef
input returns undef.

#### `peadm::certname(Variant[Target,
          String,
          Undef,
          Array[Target,1,1],
          Array[String,1,1],
          Array[Undef,1,1],
          Array[Any,0,0]] $target)`

This function accepts a variety of data types which could represent single
targets, and returns the certname corresponding to the input.

For Target objects, or arrays of a single Target object, a "certname" var can
be set, which determines that target's certname. Otherwise, the target's name
is its certname. For strings, the certname is equal to the string. Undef
input returns undef.

Returns: `Variant[String, Undef]`

##### `target`

Data type: `Variant[Target,
          String,
          Undef,
          Array[Target,1,1],
          Array[String,1,1],
          Array[Undef,1,1],
          Array[Any,0,0]]`



### <a name="peadmconvert_hash"></a>`peadm::convert_hash`

Type: Puppet Language

converts two arrays into hash

#### Examples

##### 

```puppet
peadm::convert_hash(['type', 'status'], [['xl', 'running'], ['large', 'failed']])
[
  { type => xl, status => running}, { type => large, status => failed }
]
```

#### `peadm::convert_hash(Array $keys, Array[Array] $values)`

The peadm::convert_hash function.

Returns: `Array`

##### Examples

###### 

```puppet
peadm::convert_hash(['type', 'status'], [['xl', 'running'], ['large', 'failed']])
[
  { type => xl, status => running}, { type => large, status => failed }
]
```

##### `keys`

Data type: `Array`

an array of key names to be merged into the hash

##### `values`

Data type: `Array[Array]`

data to be merged into an array with the keys

### <a name="peadmconvert_status"></a>`peadm::convert_status`

Type: Puppet Language

Transforms a value in a human readable status with or without colors

#### Examples

##### With colors

```puppet
peadm::convert_status(true) = "\e[32moperational\e[0m"
```

##### Without colors

```puppet
peadm::convert_status(true, 0, false) = "operational"
```

##### Using integers where 1 of 2 services has failed

```puppet
peadm::convert_status(1, 2, false) = "degraded"
```

##### Using integers where 2 of 2 services has failed

```puppet
peadm::convert_status(2, 2, false) = "failed"
```

##### Using integers where 0 of 2 services has failed

```puppet
peadm::convert_status(0, 2, false) = "operational"
```

#### `peadm::convert_status(Variant[String,Boolean, Integer] $status, Optional[Integer] $total = 0, Optional[Boolean] $use_colors = true)`

The peadm::convert_status function.

Returns: `String` A status as a string with or without color

##### Examples

###### With colors

```puppet
peadm::convert_status(true) = "\e[32moperational\e[0m"
```

###### Without colors

```puppet
peadm::convert_status(true, 0, false) = "operational"
```

###### Using integers where 1 of 2 services has failed

```puppet
peadm::convert_status(1, 2, false) = "degraded"
```

###### Using integers where 2 of 2 services has failed

```puppet
peadm::convert_status(2, 2, false) = "failed"
```

###### Using integers where 0 of 2 services has failed

```puppet
peadm::convert_status(0, 2, false) = "operational"
```

##### `status`

Data type: `Variant[String,Boolean, Integer]`

A value of true, false, degraded, or an Integer that represents number of non operationally services
If using an integer, you must also supply the total amount of services

##### `total`

Data type: `Optional[Integer]`

the total number of services, used only when the status is an integer

##### `use_colors`

Data type: `Optional[Boolean]`

Adds colors to the status, defaults to true

### <a name="peadmdetermine_status"></a>`peadm::determine_status`

Type: Puppet Language

}

#### Examples

##### 

```puppet
peadm::determine_status($data, true)
{
 "failed" => {
           "activity/pe-std-replica.puppet.vm" => false,
         "classifier/pe-std-replica.puppet.vm" => false,
   "file-sync-client/pe-std-replica.puppet.vm" => false,
             "master/pe-std-replica.puppet.vm" => false,
           "puppetdb/pe-std-replica.puppet.vm" => false,
               "rbac/pe-std-replica.puppet.vm" => false
 },
 "passed" => {
            "activity-service/pe-std.puppet.vm" => true,
              "broker-service/pe-std.puppet.vm" => true,
          "classifier-service/pe-std.puppet.vm" => true,
        "code-manager-service/pe-std.puppet.vm" => true,
    "file-sync-client-service/pe-std.puppet.vm" => true,
   "file-sync-storage-service/pe-std.puppet.vm" => true,
        "orchestrator-service/pe-std.puppet.vm" => true,
                   "pe-master/pe-std.puppet.vm" => true,
             "puppetdb-status/pe-std.puppet.vm" => true,
                "rbac-service/pe-std.puppet.vm" => true
 },
  "state" => {
            "activity-service/pe-std.puppet.vm" => true,
            "activity/pe-std-replica.puppet.vm" => false,
              "broker-service/pe-std.puppet.vm" => true,
          "classifier-service/pe-std.puppet.vm" => true,
          "classifier/pe-std-replica.puppet.vm" => false,
        "code-manager-service/pe-std.puppet.vm" => true,
    "file-sync-client-service/pe-std.puppet.vm" => true,
    "file-sync-client/pe-std-replica.puppet.vm" => false,
   "file-sync-storage-service/pe-std.puppet.vm" => true,
              "master/pe-std-replica.puppet.vm" => false,
        "orchestrator-service/pe-std.puppet.vm" => true,
                   "pe-master/pe-std.puppet.vm" => true,
             "puppetdb-status/pe-std.puppet.vm" => true,
            "puppetdb/pe-std-replica.puppet.vm" => false,
                "rbac-service/pe-std.puppet.vm" => true,
                "rbac/pe-std-replica.puppet.vm" => false
 },
 "status" => "\e[33mdegraded\e[0m"
```

#### `peadm::determine_status(Array $status_data, Boolean $use_colors = true)`

}

Returns: `Hash` A simplified hash of of status data for the given stack

##### Examples

###### 

```puppet
peadm::determine_status($data, true)
{
 "failed" => {
           "activity/pe-std-replica.puppet.vm" => false,
         "classifier/pe-std-replica.puppet.vm" => false,
   "file-sync-client/pe-std-replica.puppet.vm" => false,
             "master/pe-std-replica.puppet.vm" => false,
           "puppetdb/pe-std-replica.puppet.vm" => false,
               "rbac/pe-std-replica.puppet.vm" => false
 },
 "passed" => {
            "activity-service/pe-std.puppet.vm" => true,
              "broker-service/pe-std.puppet.vm" => true,
          "classifier-service/pe-std.puppet.vm" => true,
        "code-manager-service/pe-std.puppet.vm" => true,
    "file-sync-client-service/pe-std.puppet.vm" => true,
   "file-sync-storage-service/pe-std.puppet.vm" => true,
        "orchestrator-service/pe-std.puppet.vm" => true,
                   "pe-master/pe-std.puppet.vm" => true,
             "puppetdb-status/pe-std.puppet.vm" => true,
                "rbac-service/pe-std.puppet.vm" => true
 },
  "state" => {
            "activity-service/pe-std.puppet.vm" => true,
            "activity/pe-std-replica.puppet.vm" => false,
              "broker-service/pe-std.puppet.vm" => true,
          "classifier-service/pe-std.puppet.vm" => true,
          "classifier/pe-std-replica.puppet.vm" => false,
        "code-manager-service/pe-std.puppet.vm" => true,
    "file-sync-client-service/pe-std.puppet.vm" => true,
    "file-sync-client/pe-std-replica.puppet.vm" => false,
   "file-sync-storage-service/pe-std.puppet.vm" => true,
              "master/pe-std-replica.puppet.vm" => false,
        "orchestrator-service/pe-std.puppet.vm" => true,
                   "pe-master/pe-std.puppet.vm" => true,
             "puppetdb-status/pe-std.puppet.vm" => true,
            "puppetdb/pe-std-replica.puppet.vm" => false,
                "rbac-service/pe-std.puppet.vm" => true,
                "rbac/pe-std-replica.puppet.vm" => false
 },
 "status" => "\e[33mdegraded\e[0m"
```

##### `status_data`

Data type: `Array`

Raw json data as returned by puppet infra status --format=json

##### `use_colors`

Data type: `Boolean`

Adds colors to the status, defaults to true

### <a name="peadmfail_on_transport"></a>`peadm::fail_on_transport`

Type: Puppet Language

Fails if any nodes have the chosen transport.

Useful for excluding PCP when it's not appopriate

#### `peadm::fail_on_transport(TargetSpec $nodes, String $transport)`

Fails if any nodes have the chosen transport.

Useful for excluding PCP when it's not appopriate

Returns: `Any`

##### `nodes`

Data type: `TargetSpec`



##### `transport`

Data type: `String`



### <a name="peadmfile_content_upload"></a>`peadm::file_content_upload`

Type: Ruby 4.x API

The peadm::file_content_upload function.

#### `peadm::file_content_upload(String[1] $content, String[1] $destination, TargetOrTargets *$targets)`

The peadm::file_content_upload function.

Returns: `Any`

##### `content`

Data type: `String[1]`



##### `destination`

Data type: `String[1]`



##### `*targets`

Data type: `TargetOrTargets`



### <a name="peadmfile_or_content"></a>`peadm::file_or_content`

Type: Puppet Language

The peadm::file_or_content function.

#### `peadm::file_or_content(String $param_name, Variant[String, Undef] $file, Variant[String, Undef] $content)`

The peadm::file_or_content function.

Returns: `Any`

##### `param_name`

Data type: `String`



##### `file`

Data type: `Variant[String, Undef]`



##### `content`

Data type: `Variant[String, Undef]`



### <a name="peadmflatten_compact"></a>`peadm::flatten_compact`

Type: Puppet Language

The peadm::flatten_compact function.

#### `peadm::flatten_compact(Array $input)`

The peadm::flatten_compact function.

Returns: `Any`

##### `input`

Data type: `Array`



### <a name="peadmgenerate_pe_conf"></a>`peadm::generate_pe_conf`

Type: Puppet Language

Generate a pe.conf file in JSON format

#### `peadm::generate_pe_conf(Hash $settings)`

The peadm::generate_pe_conf function.

Returns: `String`

##### `settings`

Data type: `Hash`

A hash of settings to set in the config file. Any keys that are set to
undef will not be included in the config file.

### <a name="peadmget_targets"></a>`peadm::get_targets`

Type: Puppet Language

Accept undef or a SingleTargetSpec, and return an Array[Target, 1, 0].
This differs from get_target() in that:
  - It returns an Array[Target, 1, 0], rather than a Target
  - It will accept undef and return [ ].

#### `peadm::get_targets(Variant[TargetSpec, Undef] $spec, Optional[Integer[1,1]] $count = undef)`

Accept undef or a SingleTargetSpec, and return an Array[Target, 1, 0].
This differs from get_target() in that:
  - It returns an Array[Target, 1, 0], rather than a Target
  - It will accept undef and return [ ].

Returns: `Any`

##### `spec`

Data type: `Variant[TargetSpec, Undef]`



##### `count`

Data type: `Optional[Integer[1,1]]`



### <a name="peadmnode_manager_yaml_location"></a>`peadm::node_manager_yaml_location`

Type: Ruby 4.x API

The peadm::node_manager_yaml_location function.

#### `peadm::node_manager_yaml_location()`

The peadm::node_manager_yaml_location function.

Returns: `Any`

### <a name="peadmoid"></a>`peadm::oid`

Type: Puppet Language

The peadm::oid function.

#### `peadm::oid(String $short_name)`

The peadm::oid function.

Returns: `Any`

##### `short_name`

Data type: `String`



### <a name="peadmplan_step"></a>`peadm::plan_step`

Type: Ruby 4.x API

The peadm::plan_step function.

#### `peadm::plan_step(String $step_name, Callable &$block)`

The peadm::plan_step function.

Returns: `Any`

##### `step_name`

Data type: `String`



##### `&block`

Data type: `Callable`



### <a name="peadmwait_until_service_ready"></a>`peadm::wait_until_service_ready`

Type: Puppet Language

A convenience function to help remember port numbers for services and handle
running the wait_until_service_ready task

#### `peadm::wait_until_service_ready(String $service, TargetSpec $target)`

A convenience function to help remember port numbers for services and handle
running the wait_until_service_ready task

Returns: `Any`

##### `service`

Data type: `String`



##### `target`

Data type: `TargetSpec`



## Data types

### <a name="peadmpe_version"></a>`Peadm::Pe_version`

The Peadm::Pe_version data type.

Alias of

```puppet
Pattern[/^\d+\.\d+\.\d+(-.+)?$/]
```

### <a name="peadmpem"></a>`Peadm::Pem`

The Peadm::Pem data type.

Alias of

```puppet
Pattern[/^-----BEGIN/]
```

### <a name="peadmsingletargetspec"></a>`Peadm::SingleTargetSpec`

A SingleTargetSpec represents any String, Target or single-element array of
one or the other that can be passed to get_targets() to return an
Array[Target, 1, 1]. This is a constrained type variant of
Boltlib::TargetSpec for use when a _single_ target is valid, but multiple
targets are not.

Alias of

```puppet
Variant[Pattern[/\A[^[:space:],]+\z/], Target, Array[Peadm::SingleTargetSpec, 1, 1]]
```

## Tasks

### <a name="agent_install"></a>`agent_install`

Install the Puppet agent from a master

**Supports noop?** false

#### Parameters

##### `server`

Data type: `String`

The resolvable name of the Puppet server to install from

##### `install_flags`

Data type: `Array[String]`

Positional arguments to pass to the shell installer

### <a name="agent_upgrade"></a>`agent_upgrade`

Upgrade the target system using upgrade.bash from a master

**Supports noop?** false

#### Parameters

##### `server`

Data type: `String`

The resolvable name of the Puppet server to upgrade from

### <a name="backup_classification"></a>`backup_classification`

A task to call the classification api and write to file

**Supports noop?** false

#### Parameters

##### `directory`

Data type: `String`

The directory to write the classification output to. Directory must exist

### <a name="cert_data"></a>`cert_data`

Return certificate data related to the Puppet agent

**Supports noop?** false

### <a name="code_manager"></a>`code_manager`

Perform various code manager actions

**Supports noop?** false

#### Parameters

##### `action`

Data type: `String`

What code manager action to perform. For example: 'deploy production'; 'flush-environment-cache'; 'file-sync commit'

### <a name="code_sync_status"></a>`code_sync_status`

A task to confirm code is in sync accross the cluster for clusters with code manager configured

**Supports noop?** false

#### Parameters

##### `environments`

Data type: `Array`

A list of environments to check, pass a single value of all for all

### <a name="divert_code_manager"></a>`divert_code_manager`

Divert the code manager live-dir setting

**Supports noop?** false

### <a name="download"></a>`download`

Download a file using curl

**Supports noop?** false

#### Parameters

##### `source`

Data type: `String`

Where to download the file from

##### `path`

Data type: `String`

Where to save the downloaded file

##### `verify_download`

Data type: `Boolean`

Whether to check the integrity of the downloaded file

##### `key_server`

Data type: `String`

The GPG keyserver to retrieve GPG keys from

### <a name="enable_replica"></a>`enable_replica`

Execute the enable replica puppet command

**Supports noop?** false

#### Parameters

##### `replica`

Data type: `String`

The name of the replica to enable

##### `token_file`

Data type: `Optional[String]`

The name of the token file to use for auth

### <a name="filesize"></a>`filesize`

Return the size of a file in bytes

**Supports noop?** false

#### Parameters

##### `path`

Data type: `String`

Path to the file to return the size of

### <a name="get_peadm_config"></a>`get_peadm_config`

Run on a PE primary node to return the currently configured PEAdm parameters

**Supports noop?** false

### <a name="infrastatus"></a>`infrastatus`

Runs puppet infra status and returns the output

**Supports noop?** false

#### Parameters

##### `format`

Data type: `Enum[json,text]`

The type of output to return

### <a name="mkdir_p_file"></a>`mkdir_p_file`

Create a file with the specified content at the specified location

**Supports noop?** false

#### Parameters

##### `path`

Data type: `String`

The fully qualified path of the file to create

##### `content`

Data type: `String`

The content to create the file with

##### `owner`

Data type: `Optional[String]`

The file owner

##### `group`

Data type: `Optional[String]`

The file group

##### `mode`

Data type: `Optional[String]`

The file mode

##### `chown_r`

Data type: `Optional[String]`

If supplied, recursively chown starting at this path

### <a name="mv"></a>`mv`

Wrapper task for mv command

**Supports noop?** false

#### Parameters

##### `source`

Data type: `String`

Current path of file

##### `target`

Data type: `String`

New path of file

### <a name="pe_install"></a>`pe_install`

Install Puppet Enterprise from a tarball

**Supports noop?** false

#### Parameters

##### `tarball`

Data type: `String`

The path to the Puppet Enterprise tarball

##### `peconf`

Data type: `Optional[String]`

The path to the pe.conf file

##### `install_extra_large`

Data type: `Optional[Boolean]`

If true, optimize task for known manual issues with extra-large installs. Do not use for upgrades

##### `puppet_service_ensure`

Data type: `Optional[Enum['stopped']]`

If 'stopped', ensure the Puppet agent is not running when install completes

### <a name="pe_uninstall"></a>`pe_uninstall`

Uninstall Puppet Enterprise

**Supports noop?** false

### <a name="precheck"></a>`precheck`

Return pre-check information about a system

**Supports noop?** false

### <a name="provision_replica"></a>`provision_replica`

Execute the replica provision puppet command

**Supports noop?** false

#### Parameters

##### `replica`

Data type: `String`

The name of the replica to provision

##### `token_file`

Data type: `Optional[String]`

The name of the token-file for auth

##### `legacy`

Data type: `Boolean`

Set to true if provisioning a replica for PE 2019.5 or older. Defaults to false

### <a name="puppet_infra_upgrade"></a>`puppet_infra_upgrade`

Execute the puppet infra upgrade command

**Supports noop?** false

#### Parameters

##### `type`

Data type: `Enum[compiler,replica]`

Which kind of infra node to upgrade

##### `targets`

Data type: `Array[String]`

The certnames of the targets to upgrade

##### `token_file`

Data type: `Optional[String]`

The path to the token file to use

##### `wait_until_connected_timeout`

Data type: `Integer`

How many seconds to wait for targets to be connected to the orchestrator

### <a name="puppet_runonce"></a>`puppet_runonce`

Run the Puppet agent one time

**Supports noop?** false

#### Parameters

##### `noop`

Data type: `Optional[Boolean]`

If true, run Puppet in no-op mode

### <a name="rbac_token"></a>`rbac_token`

Get and save an rbac token for the root user, admin rbac user

**Supports noop?** false

#### Parameters

##### `password`

Data type: `String`

The password for the admin user

### <a name="read_file"></a>`read_file`

Read the contents of a file

**Supports noop?** false

#### Parameters

##### `path`

Data type: `String`

Path to the file to read

### <a name="sign_csr"></a>`sign_csr`

Submit a certificate signing request

**Supports noop?** false

#### Parameters

##### `certnames`

Data type: `Array[String]`

A list of certnames to sign

### <a name="ssl_clean"></a>`ssl_clean`

Clean an agent's certificate

**Supports noop?** false

#### Parameters

##### `certname`

Data type: `String`

The certname to clean

### <a name="submit_csr"></a>`submit_csr`

Submit a certificate signing request

**Supports noop?** false

#### Parameters

##### `dns_alt_names`

Data type: `Optional[Array[String]]`

DNS Alternative Names to request for the certificate

### <a name="wait_until_service_ready"></a>`wait_until_service_ready`

Return when the orchestrator service is healthy, or timeout after 15 seconds

**Supports noop?** false

#### Parameters

##### `service`

Data type: `Enum[all, ca, pe-master, orchestrator-service]`

What service to check. For example: all, pe-master, orchestrator-service

##### `port`

Data type: `Enum['8140', '8143']`

Which port to query the status API on

## Plans

### <a name="peadmbackup"></a>`peadm::backup`

This plan can backup data as outlined at insert doc

#### Parameters

The following parameters are available in the `peadm::backup` plan:

* [`primary_host`](#primary_host)
* [`backup_orchestrator`](#backup_orchestrator)
* [`backup_rbac`](#backup_rbac)
* [`backup_activity`](#backup_activity)
* [`backup_ca_ssl`](#backup_ca_ssl)
* [`backup_puppetdb`](#backup_puppetdb)
* [`backup_classification`](#backup_classification)
* [`output_directory`](#output_directory)

##### <a name="primary_host"></a>`primary_host`

Data type: `Peadm::SingleTargetSpec`



##### <a name="backup_orchestrator"></a>`backup_orchestrator`

Data type: `Boolean`



Default value: ``true``

##### <a name="backup_rbac"></a>`backup_rbac`

Data type: `Boolean`



Default value: ``true``

##### <a name="backup_activity"></a>`backup_activity`

Data type: `Boolean`



Default value: ``true``

##### <a name="backup_ca_ssl"></a>`backup_ca_ssl`

Data type: `Boolean`



Default value: ``true``

##### <a name="backup_puppetdb"></a>`backup_puppetdb`

Data type: `Boolean`



Default value: ``false``

##### <a name="backup_classification"></a>`backup_classification`

Data type: `Boolean`



Default value: ``true``

##### <a name="output_directory"></a>`output_directory`

Data type: `String`



Default value: `'/tmp'`

### <a name="peadmconvert"></a>`peadm::convert`

This plan sets required certificate extensions on PE nodes, and configures
the required PE node groups to make an existing cluster compatible with
management using PEAdm.

#### Parameters

The following parameters are available in the `peadm::convert` plan:

* [`primary_host`](#primary_host)
* [`replica_host`](#replica_host)
* [`compiler_hosts`](#compiler_hosts)
* [`primary_postgresql_host`](#primary_postgresql_host)
* [`replica_postgresql_host`](#replica_postgresql_host)
* [`compiler_pool_address`](#compiler_pool_address)
* [`internal_compiler_a_pool_address`](#internal_compiler_a_pool_address)
* [`internal_compiler_b_pool_address`](#internal_compiler_b_pool_address)
* [`dns_alt_names`](#dns_alt_names)
* [`begin_at_step`](#begin_at_step)

##### <a name="primary_host"></a>`primary_host`

Data type: `Peadm::SingleTargetSpec`



##### <a name="replica_host"></a>`replica_host`

Data type: `Optional[Peadm::SingleTargetSpec]`



Default value: ``undef``

##### <a name="compiler_hosts"></a>`compiler_hosts`

Data type: `Optional[TargetSpec]`



Default value: ``undef``

##### <a name="primary_postgresql_host"></a>`primary_postgresql_host`

Data type: `Optional[Peadm::SingleTargetSpec]`



Default value: ``undef``

##### <a name="replica_postgresql_host"></a>`replica_postgresql_host`

Data type: `Optional[Peadm::SingleTargetSpec]`



Default value: ``undef``

##### <a name="compiler_pool_address"></a>`compiler_pool_address`

Data type: `String`



Default value: `$primary_host`

##### <a name="internal_compiler_a_pool_address"></a>`internal_compiler_a_pool_address`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="internal_compiler_b_pool_address"></a>`internal_compiler_b_pool_address`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="dns_alt_names"></a>`dns_alt_names`

Data type: `Array[String]`



Default value: `[ ]`

##### <a name="begin_at_step"></a>`begin_at_step`

Data type: `Optional[Enum[
    'modify-primary-certs',
    'modify-infra-certs',
    'convert-node-groups',
    'finalize']]`



Default value: ``undef``

### <a name="peadminstall"></a>`peadm::install`

Install a new PE cluster

#### Parameters

The following parameters are available in the `peadm::install` plan:

* [`compiler_pool_address`](#compiler_pool_address)
* [`internal_compiler_a_pool_address`](#internal_compiler_a_pool_address)
* [`internal_compiler_b_pool_address`](#internal_compiler_b_pool_address)
* [`primary_host`](#primary_host)
* [`replica_host`](#replica_host)
* [`compiler_hosts`](#compiler_hosts)
* [`primary_postgresql_host`](#primary_postgresql_host)
* [`replica_postgresql_host`](#replica_postgresql_host)
* [`console_password`](#console_password)
* [`version`](#version)
* [`dns_alt_names`](#dns_alt_names)
* [`pe_conf_data`](#pe_conf_data)
* [`r10k_remote`](#r10k_remote)
* [`r10k_private_key_file`](#r10k_private_key_file)
* [`r10k_private_key_content`](#r10k_private_key_content)
* [`deploy_environment`](#deploy_environment)
* [`license_key_file`](#license_key_file)
* [`license_key_content`](#license_key_content)
* [`stagingdir`](#stagingdir)
* [`download_mode`](#download_mode)
* [`permit_unsafe_versions`](#permit_unsafe_versions)

##### <a name="compiler_pool_address"></a>`compiler_pool_address`

Data type: `Optional[String]`

The service address used by agents to connect to compilers, or the Puppet
service. Typically this is a load balancer.

Default value: ``undef``

##### <a name="internal_compiler_a_pool_address"></a>`internal_compiler_a_pool_address`

Data type: `Optional[String]`

A load balancer address directing traffic to any of the "A" pool
compilers. This is used for DR configuration in large and extra large
architectures.

Default value: ``undef``

##### <a name="internal_compiler_b_pool_address"></a>`internal_compiler_b_pool_address`

Data type: `Optional[String]`

A load balancer address directing traffic to any of the "B" pool
compilers. This is used for DR configuration in large and extra large
architectures.

Default value: ``undef``

##### <a name="primary_host"></a>`primary_host`

Data type: `Peadm::SingleTargetSpec`



##### <a name="replica_host"></a>`replica_host`

Data type: `Optional[Peadm::SingleTargetSpec]`



Default value: ``undef``

##### <a name="compiler_hosts"></a>`compiler_hosts`

Data type: `Optional[TargetSpec]`



Default value: ``undef``

##### <a name="primary_postgresql_host"></a>`primary_postgresql_host`

Data type: `Optional[Peadm::SingleTargetSpec]`



Default value: ``undef``

##### <a name="replica_postgresql_host"></a>`replica_postgresql_host`

Data type: `Optional[Peadm::SingleTargetSpec]`



Default value: ``undef``

##### <a name="console_password"></a>`console_password`

Data type: `String`



##### <a name="version"></a>`version`

Data type: `Peadm::Pe_version`



Default value: `'2019.8.8'`

##### <a name="dns_alt_names"></a>`dns_alt_names`

Data type: `Optional[Array[String]]`



Default value: ``undef``

##### <a name="pe_conf_data"></a>`pe_conf_data`

Data type: `Optional[Hash]`



Default value: `{ }`

##### <a name="r10k_remote"></a>`r10k_remote`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="r10k_private_key_file"></a>`r10k_private_key_file`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="r10k_private_key_content"></a>`r10k_private_key_content`

Data type: `Optional[Peadm::Pem]`



Default value: ``undef``

##### <a name="deploy_environment"></a>`deploy_environment`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="license_key_file"></a>`license_key_file`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="license_key_content"></a>`license_key_content`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="stagingdir"></a>`stagingdir`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="download_mode"></a>`download_mode`

Data type: `Enum[direct,bolthost]`



Default value: `'bolthost'`

##### <a name="permit_unsafe_versions"></a>`permit_unsafe_versions`

Data type: `Boolean`



Default value: ``false``

### <a name="peadmmodify_certificate"></a>`peadm::modify_certificate`

Certificates can be modified by adding extensions, removing extensions, or
setting DNS alternative names.

#### Parameters

The following parameters are available in the `peadm::modify_certificate` plan:

* [`targets`](#targets)
* [`primary_host`](#primary_host)
* [`add_extensions`](#add_extensions)
* [`remove_extensions`](#remove_extensions)
* [`dns_alt_names`](#dns_alt_names)
* [`force_regenerate`](#force_regenerate)

##### <a name="targets"></a>`targets`

Data type: `TargetSpec`



##### <a name="primary_host"></a>`primary_host`

Data type: `Peadm::SingleTargetSpec`



##### <a name="add_extensions"></a>`add_extensions`

Data type: `Hash`



Default value: `{ }`

##### <a name="remove_extensions"></a>`remove_extensions`

Data type: `Array`



Default value: `[ ]`

##### <a name="dns_alt_names"></a>`dns_alt_names`

Data type: `Optional[Array]`



Default value: ``undef``

##### <a name="force_regenerate"></a>`force_regenerate`

Data type: `Boolean`



Default value: ``false``

### <a name="peadmstatus"></a>`peadm::status`

Return status information from one or more PE clusters in a table format

#### Examples

##### 

```puppet
peadm::status($targets, 'table', true, true)
```

#### Parameters

The following parameters are available in the `peadm::status` plan:

* [`targets`](#targets)
* [`format`](#format)
* [`summarize`](#summarize)
* [`verbose`](#verbose)
* [`colors`](#colors)

##### <a name="targets"></a>`targets`

Data type: `TargetSpec`

These are a list of the primary puppetservers from one or multiple puppet stacks

##### <a name="format"></a>`format`

Data type: `Enum[json,table]`

The output format to dump to stdout (json or table)

Default value: `'table'`

##### <a name="summarize"></a>`summarize`

Data type: `Boolean`

Controls the type of json output to render, defaults to true

Default value: ``true``

##### <a name="verbose"></a>`verbose`

Data type: `Boolean`

Toggles the output to show all the operationally services, can be loads more data

Default value: ``false``

##### <a name="colors"></a>`colors`

Data type: `Boolean`

Toggles the usage of colors, you may want to disable if the format is json

Default value: `$format`

### <a name="peadmupgrade"></a>`peadm::upgrade`

Upgrade a PEAdm-managed cluster

#### Parameters

The following parameters are available in the `peadm::upgrade` plan:

* [`compiler_pool_address`](#compiler_pool_address)
* [`internal_compiler_a_pool_address`](#internal_compiler_a_pool_address)
* [`internal_compiler_b_pool_address`](#internal_compiler_b_pool_address)
* [`primary_host`](#primary_host)
* [`replica_host`](#replica_host)
* [`compiler_hosts`](#compiler_hosts)
* [`primary_postgresql_host`](#primary_postgresql_host)
* [`replica_postgresql_host`](#replica_postgresql_host)
* [`version`](#version)
* [`token_file`](#token_file)
* [`stagingdir`](#stagingdir)
* [`download_mode`](#download_mode)
* [`permit_unsafe_versions`](#permit_unsafe_versions)
* [`begin_at_step`](#begin_at_step)

##### <a name="compiler_pool_address"></a>`compiler_pool_address`

Data type: `Optional[String]`

The service address used by agents to connect to compilers, or the Puppet
service. Typically this is a load balancer.

Default value: ``undef``

##### <a name="internal_compiler_a_pool_address"></a>`internal_compiler_a_pool_address`

Data type: `Optional[String]`

A load balancer address directing traffic to any of the "A" pool
compilers. This is used for DR configuration in large and extra large
architectures.

Default value: ``undef``

##### <a name="internal_compiler_b_pool_address"></a>`internal_compiler_b_pool_address`

Data type: `Optional[String]`

A load balancer address directing traffic to any of the "B" pool
compilers. This is used for DR configuration in large and extra large
architectures.

Default value: ``undef``

##### <a name="primary_host"></a>`primary_host`

Data type: `Peadm::SingleTargetSpec`



##### <a name="replica_host"></a>`replica_host`

Data type: `Optional[Peadm::SingleTargetSpec]`



Default value: ``undef``

##### <a name="compiler_hosts"></a>`compiler_hosts`

Data type: `Optional[TargetSpec]`



Default value: ``undef``

##### <a name="primary_postgresql_host"></a>`primary_postgresql_host`

Data type: `Optional[Peadm::SingleTargetSpec]`



Default value: ``undef``

##### <a name="replica_postgresql_host"></a>`replica_postgresql_host`

Data type: `Optional[Peadm::SingleTargetSpec]`



Default value: ``undef``

##### <a name="version"></a>`version`

Data type: `Peadm::Pe_version`



##### <a name="token_file"></a>`token_file`

Data type: `Optional[String]`



Default value: ``undef``

##### <a name="stagingdir"></a>`stagingdir`

Data type: `String`



Default value: `'/tmp'`

##### <a name="download_mode"></a>`download_mode`

Data type: `Enum[direct,bolthost]`



Default value: `'bolthost'`

##### <a name="permit_unsafe_versions"></a>`permit_unsafe_versions`

Data type: `Boolean`



Default value: ``false``

##### <a name="begin_at_step"></a>`begin_at_step`

Data type: `Optional[Enum[
    'upgrade-primary',
    'upgrade-node-groups',
    'upgrade-primary-compilers',
    'upgrade-replica',
    'upgrade-replica-compilers',
    'finalize']]`



Default value: ``undef``

